
#ifndef KMM_SELECTIONS_EXPORT_H
#define KMM_SELECTIONS_EXPORT_H

#ifdef KMM_SELECTIONS_STATIC_DEFINE
#  define KMM_SELECTIONS_EXPORT
#  define KMM_SELECTIONS_NO_EXPORT
#else
#  ifndef KMM_SELECTIONS_EXPORT
#    ifdef kmm_selections_EXPORTS
        /* We are building this library */
#      define KMM_SELECTIONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KMM_SELECTIONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KMM_SELECTIONS_NO_EXPORT
#    define KMM_SELECTIONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KMM_SELECTIONS_DEPRECATED
#  define KMM_SELECTIONS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KMM_SELECTIONS_DEPRECATED_EXPORT
#  define KMM_SELECTIONS_DEPRECATED_EXPORT KMM_SELECTIONS_EXPORT KMM_SELECTIONS_DEPRECATED
#endif

#ifndef KMM_SELECTIONS_DEPRECATED_NO_EXPORT
#  define KMM_SELECTIONS_DEPRECATED_NO_EXPORT KMM_SELECTIONS_NO_EXPORT KMM_SELECTIONS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KMM_SELECTIONS_NO_DEPRECATED
#    define KMM_SELECTIONS_NO_DEPRECATED
#  endif
#endif

#endif /* KMM_SELECTIONS_EXPORT_H */
